#[non_exhaustive]pub enum MetadataFilter {
Eq {
field: String,
value: Value,
},
Ne {
field: String,
value: Value,
},
Gt {
field: String,
value: Value,
},
Gte {
field: String,
value: Value,
},
Lt {
field: String,
value: Value,
},
Lte {
field: String,
value: Value,
},
In {
field: String,
values: Vec<Value>,
},
NotIn {
field: String,
values: Vec<Value>,
},
And(Vec<MetadataFilter>),
Or(Vec<MetadataFilter>),
Not(Box<MetadataFilter>),
}Expand description
Metadata filter for vector search. Applied as a pre-filter (Roaring bitmap) or post-filter depending on selectivity.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Eq
Field equals a specific value.
Ne
Field does not equal a specific value.
Gt
Field is greater than a value (numeric/string).
Gte
Field is greater than or equal to a value.
Lt
Field is less than a value.
Lte
Field is less than or equal to a value.
In
Field value is in a set.
NotIn
Field value is not in a set.
And(Vec<MetadataFilter>)
Logical AND of multiple filters.
Or(Vec<MetadataFilter>)
Logical OR of multiple filters.
Not(Box<MetadataFilter>)
Logical NOT of a filter.
Implementations
Sourceimpl MetadataFilter
impl MetadataFilter
Sourcepub fn eq(field: impl Into<String>, value: impl Into<Value>) -> MetadataFilter
pub fn eq(field: impl Into<String>, value: impl Into<Value>) -> MetadataFilter
Shorthand: field == value.
Sourcepub fn and(filters: Vec<MetadataFilter>) -> MetadataFilter
pub fn and(filters: Vec<MetadataFilter>) -> MetadataFilter
Shorthand: combine filters with AND.
Sourcepub fn or(filters: Vec<MetadataFilter>) -> MetadataFilter
pub fn or(filters: Vec<MetadataFilter>) -> MetadataFilter
Shorthand: combine filters with OR.